Skip to contents

Function to save the heat map generated by pheatmap, as first written by Matt Whitaker (https://gist.github.com/mathzero)

Usage

save_pheatmap(x, filename, width = 12, height = 12)

Arguments

x

pheatmap object

filename

Desired filename, containing png or pdf

width

Plot width for file

height

Plot height for file

Details

function detects '.png' or '.pdf' in the declared filename and assigns that file type