Simultaneous GGPlot Save as PDF, PNG, SVG
save_ggplot.RdThis function saves the specified plots built using ggplot2 as png, pdf, and svg files. You can specify subfolders for each data subset or store plots however you want in the plot directory.
Arguments
- filename
What you want the saved plot to be named
- plot
Name of the plot object to be saved
- path
Path to the designated plot folder. These is where subfolders will be built for each plot file type.
Boolean. Whether to save plot as a pdf.
- svg
Boolean. Whether to save plot as a svg.
- png
Boolean. Whether to save plot as a png.
- height
Plot height
- width
Plot width